# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/response/response_vod.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.base.models.base import base_pb2 as base_dot_base__pb2
from volcengine.vod.models.business import vod_play_pb2 as vod_dot_business_dot_vod__play__pb2
from volcengine.vod.models.business import vod_media_pb2 as vod_dot_business_dot_vod__media__pb2
from volcengine.vod.models.business import vod_upload_pb2 as vod_dot_business_dot_vod__upload__pb2
from volcengine.vod.models.business import vod_workflow_pb2 as vod_dot_business_dot_vod__workflow__pb2
from volcengine.vod.models.business import vod_edit_pb2 as vod_dot_business_dot_vod__edit__pb2
from volcengine.vod.models.business import vod_space_pb2 as vod_dot_business_dot_vod__space__pb2
from volcengine.vod.models.business import vod_cdn_pb2 as vod_dot_business_dot_vod__cdn__pb2
from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2
from volcengine.vod.models.business import vod_smart_strategy_pb2 as vod_dot_business_dot_vod__smart__strategy__pb2
from volcengine.vod.models.business import vod_apps_manage_pb2 as vod_dot_business_dot_vod__apps__manage__pb2
from volcengine.vod.models.business import vod_measure_pb2 as vod_dot_business_dot_vod__measure__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvod/response/response_vod.proto\x12\x1eVolcengine.Vod.Models.Response\x1a\x0f\x62\x61se/base.proto\x1a\x1bvod/business/vod_play.proto\x1a\x1cvod/business/vod_media.proto\x1a\x1dvod/business/vod_upload.proto\x1a\x1fvod/business/vod_workflow.proto\x1a\x1bvod/business/vod_edit.proto\x1a\x1cvod/business/vod_space.proto\x1a\x1avod/business/vod_cdn.proto\x1a\x1dvod/business/vod_common.proto\x1a%vod/business/vod_smart_strategy.proto\x1a\"vod/business/vod_apps_manage.proto\x1a\x1evod/business/vod_measure.proto\"\xaa\x01\n\x19VodGetAllPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodAllPlayInfoResult\"\xa3\x01\n\x16VodGetPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodPlayInfoModel\"\xb7\x01\n\x1eVodGetOriginalPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetOriginalPlayInfoResult\"\xbb\x01\n VodGetPrivateDrmPlayAuthResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodGetPrivateDrmPlayAuthResult\"\xb7\x01\n\x1eVodGetHlsDecryptionKeyResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetHlsDecryptionKeyResult\"\xd3\x01\n,VodGetPlayInfoWithLiveTimeShiftSceneResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12Z\n\x06Result\x18\x02 \x01(\x0b\x32J.Volcengine.Vod.Models.Business.VodGetPlayInfoWithLiveTimeShiftSceneResult\"\xa0\x01\n\x16VodUploadMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12=\n\x06Result\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodCommitData\"\xa7\x01\n\x1eVodQueryUploadTaskInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodQueryData\"\xa3\x01\n\x14VodUrlUploadResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodUrlResponseData\"\xaf\x01\n\x1aVodApplyUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12H\n\x06Result\x18\x02 \x01(\x0b\x32\x38.Volcengine.Vod.Models.Business.VodApplyUploadInfoResult\"\xb1\x01\n\x1bVodCommitUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodCommitUploadInfoResult\"\xa9\x01\n\x18VodGetMediaInfosResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodGetMediaInfosData\"e\n\x1aVodUpdateMediaInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xaf\x01\n\x1fVodGetRecommendedPosterResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetRecPosterData\"n\n#VodUpdateMediaPublishStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xbd\x01\n\"VodUpdateMediaStorageClassResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodUpdateMediaStorageClassData\"\xa5\x01\n\x16VodDeleteMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodDeleteMediaData\"\xaf\x01\n\x1bVodDeleteTranscodesResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12G\n\x06Result\x18\x02 \x01(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodDeleteTranscodesData\"\xa7\x01\n\x17VodGetMediaListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetMediaListData\"\xb5\x01\n\x1eVodGetSubtitleInfoListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetSubtitleInfoListData\"\xb7\x01\n\x1fVodUpdateSubtitleStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodUpdateSubtitleStatusData\"h\n\x1dVodUpdateSubtitleInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xb8\x01\n!VodGetAuditFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xb5\x01\n\x1eVodGetMLFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xbf\x01\n\"VodGetBetterFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodGetBetterFramesForAuditResult\"\xb9\x01\n\x1fVodGetAudioInfoForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.VodGetAudioInfoForAuditResult\"\xdb\x01\n0VodGetAutomaticSpeechRecognitionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12^\n\x06Result\x18\x02 \x01(\x0b\x32N.Volcengine.Vod.Models.Business.VodGetAutomaticSpeechRecognitionForAuditResult\"\xcd\x01\n)VodGetAudioEventDetectionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodGetAudioEventDetectionForAuditResult\"\xc1\x01\n$VodCreateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodCreateVideoClassificationData\"o\n$VodUpdateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"o\n$VodDeleteVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xbb\x01\n#VodListVideoClassificationsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodVideoClassificationsData\"\xa4\x01\n\x18VodListSnapshotsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.VodSnapshotData\"\xa7\x01\n\x16VodGetFileListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodGetMediaInfosData\"j\n\x1fVodExtractMediaMetaTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xab\x01\n\x18VodStartWorkflowResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodStartWorkflowResult\"\xae\x01\n\"VodRetrieveTranscodeResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.TranscodeResult\"\xbb\x01\n VodListWorkflowExecutionResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodListWorkflowExecutionResult\"\xc5\x01\n%VodGetWorkflowExecutionDetailResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12S\n\x06Result\x18\x02 \x01(\x0b\x32\x43.Volcengine.Vod.Models.Business.VodGetWorkflowExecutionDetailResult\"\xb3\x01\n%VodGetWorkflowExecutionStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x41\n\x06Result\x18\x02 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.WorkflowExecution\"\xaa\x01\n\x1cVodGetWorkflowResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x41\n\x06Result\x18\x02 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodWorkflowResult\"\xc0\x01\n$VodSubmitDirectEditTaskAsyncResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12O\n\x06Result\x18\x02 \x01(\x0b\x32?.Volcengine.Vod.Models.Business.SubmitDirectEditTaskAsyncResult\"\xb2\x01\n VodGetDirectEditProgressResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x45\n\x06Result\x18\x02 \x01(\x0b\x32\x35.Volcengine.Vod.Models.Business.GetDirectEditProgress\"\xae\x01\n\x1eVodGetDirectEditResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x03(\x0b\x32\x33.Volcengine.Vod.Models.Business.GetDirectEditResult\"a\n\x16VodCreateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\x9d\x01\n\x14VodListSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"\xa2\x01\n\x19VodGetSpaceDetailResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"a\n\x16VodUpdateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"m\n\"VodUpdateSpaceUploadConfigResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xc7\x01\n&VodDescribeVodSpaceStorageDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12T\n\x06Result\x18\x02 \x01(\x0b\x32\x44.Volcengine.Vod.Models.Business.VodDescribeVodSpaceStorageDataResult\"\xa5\x01\n\x15VodListDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodDomainConfigInfo\"\xb2\x01\n\x1fVodCreateCdnRefreshTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xb2\x01\n\x1fVodCreateCdnPreloadTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xa4\x01\n\x17VodListCdnTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodCdnTaskResult\"\xb1\x01\n\x1bVodListCdnAccessLogResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodListCdnAccessLogResult\"\xb7\x01\n\x1eVodListCdnTopAccessUrlResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodListCdnTopAccessUrlResult\"\xcd\x01\n)VodDescribeVodDomainBandwidthDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodDescribeVodDomainBandwidthDataResult\"\xb7\x01\n\x1eVodCdnStatisticsCommonResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodCdnStatisticsCommonResult\"\xa2\x01\n\x19VodDescribeIPInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodCdnIpInfo\"\xc9\x01\n\'VodDescribeVodDomainTrafficDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12U\n\x06Result\x18\x02 \x01(\x0b\x32\x45.Volcengine.Vod.Models.Business.VodDescribeVodDomainTrafficDataResult\"\xb1\x01\n\x1bVodSubmitBlockTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodSubmitBlockTasksResult\"\xb9\x01\n\x1fVodGetContentBlockTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.VodGetContentBlockTasksResult\"d\n\x19VodCreateDomainV2Response\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"j\n\x1fVodUpdateDomainExpireV2Response\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"n\n#VodUpdateDomainAuthConfigV2Response\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"m\n\"VodAddCallbackSubscriptionResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"f\n\x1bVodSetCallbackEventResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xc9\x01\n\'VodGetSmartStrategyLitePlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12U\n\x06Result\x18\x02 \x01(\x0b\x32\x45.Volcengine.Vod.Models.Business.VodGetSmartStrategyLitePlayInfoResult\"\xa5\x01\n\x15VodGetAppInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetAppInfoResult\"\xc5\x01\n%DescribeVodSpaceTranscodeDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12S\n\x06Result\x18\x02 \x01(\x0b\x32\x43.Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeDataResult\"\xc3\x01\n$DescribeVodSpaceAIStatisDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12R\n\x06Result\x18\x02 \x01(\x0b\x32\x42.Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataResult\"\xcf\x01\n*DescribeVodSpaceSubtitleStatisDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12X\n\x06Result\x18\x02 \x01(\x0b\x32H.Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataResult\"\xcb\x01\n(DescribeVodSpaceDetectStatisDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12V\n\x06Result\x18\x02 \x01(\x0b\x32\x46.Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataResult\"\xb9\x01\n\x1f\x44\x65scribeVodSnapshotDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.DescribeVodSnapshotDataResultB\xcc\x01\n)com.volcengine.service.vod.model.responseB\x0bVodResponseP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Response\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETALLPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetAllPlayInfoResponse']
_VODGETPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoResponse']
_VODGETORIGINALPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetOriginalPlayInfoResponse']
_VODGETPRIVATEDRMPLAYAUTHRESPONSE = DESCRIPTOR.message_types_by_name['VodGetPrivateDrmPlayAuthResponse']
_VODGETHLSDECRYPTIONKEYRESPONSE = DESCRIPTOR.message_types_by_name['VodGetHlsDecryptionKeyResponse']
_VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoWithLiveTimeShiftSceneResponse']
_VODUPLOADMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodUploadMediaResponse']
_VODQUERYUPLOADTASKINFORESPONSE = DESCRIPTOR.message_types_by_name['VodQueryUploadTaskInfoResponse']
_VODURLUPLOADRESPONSE = DESCRIPTOR.message_types_by_name['VodUrlUploadResponse']
_VODAPPLYUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoResponse']
_VODCOMMITUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResponse']
_VODGETMEDIAINFOSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaInfosResponse']
_VODUPDATEMEDIAINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaInfoResponse']
_VODGETRECOMMENDEDPOSTERRESPONSE = DESCRIPTOR.message_types_by_name['VodGetRecommendedPosterResponse']
_VODUPDATEMEDIAPUBLISHSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaPublishStatusResponse']
_VODUPDATEMEDIASTORAGECLASSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaStorageClassResponse']
_VODDELETEMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteMediaResponse']
_VODDELETETRANSCODESRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesResponse']
_VODGETMEDIALISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaListResponse']
_VODGETSUBTITLEINFOLISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListResponse']
_VODUPDATESUBTITLESTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusResponse']
_VODUPDATESUBTITLEINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleInfoResponse']
_VODGETAUDITFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAuditFramesForAuditResponse']
_VODGETMLFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMLFramesForAuditResponse']
_VODGETBETTERFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditResponse']
_VODGETAUDIOINFOFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditResponse']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditResponse']
_VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditResponse']
_VODCREATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationResponse']
_VODUPDATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateVideoClassificationResponse']
_VODDELETEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteVideoClassificationResponse']
_VODLISTVIDEOCLASSIFICATIONSRESPONSE = DESCRIPTOR.message_types_by_name['VodListVideoClassificationsResponse']
_VODLISTSNAPSHOTSRESPONSE = DESCRIPTOR.message_types_by_name['VodListSnapshotsResponse']
_VODGETFILELISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetFileListResponse']
_VODEXTRACTMEDIAMETATASKRESPONSE = DESCRIPTOR.message_types_by_name['VodExtractMediaMetaTaskResponse']
_VODSTARTWORKFLOWRESPONSE = DESCRIPTOR.message_types_by_name['VodStartWorkflowResponse']
_VODRETRIEVETRANSCODERESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodRetrieveTranscodeResultResponse']
_VODLISTWORKFLOWEXECUTIONRESPONSE = DESCRIPTOR.message_types_by_name['VodListWorkflowExecutionResponse']
_VODGETWORKFLOWEXECUTIONDETAILRESPONSE = DESCRIPTOR.message_types_by_name['VodGetWorkflowExecutionDetailResponse']
_VODGETWORKFLOWEXECUTIONSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetWorkflowExecutionStatusResponse']
_VODGETWORKFLOWRESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetWorkflowResultResponse']
_VODSUBMITDIRECTEDITTASKASYNCRESPONSE = DESCRIPTOR.message_types_by_name['VodSubmitDirectEditTaskAsyncResponse']
_VODGETDIRECTEDITPROGRESSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetDirectEditProgressResponse']
_VODGETDIRECTEDITRESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetDirectEditResultResponse']
_VODCREATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodCreateSpaceResponse']
_VODLISTSPACERESPONSE = DESCRIPTOR.message_types_by_name['VodListSpaceResponse']
_VODGETSPACEDETAILRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSpaceDetailResponse']
_VODUPDATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceResponse']
_VODUPDATESPACEUPLOADCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceUploadConfigResponse']
_VODDESCRIBEVODSPACESTORAGEDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodSpaceStorageDataResponse']
_VODLISTDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['VodListDomainResponse']
_VODCREATECDNREFRESHTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnRefreshTaskResponse']
_VODCREATECDNPRELOADTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnPreloadTaskResponse']
_VODLISTCDNTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTasksResponse']
_VODLISTCDNACCESSLOGRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnAccessLogResponse']
_VODLISTCDNTOPACCESSURLRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTopAccessUrlResponse']
_VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainBandwidthDataResponse']
_VODCDNSTATISTICSCOMMONRESPONSE = DESCRIPTOR.message_types_by_name['VodCdnStatisticsCommonResponse']
_VODDESCRIBEIPINFORESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeIPInfoResponse']
_VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainTrafficDataResponse']
_VODSUBMITBLOCKTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodSubmitBlockTasksResponse']
_VODGETCONTENTBLOCKTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetContentBlockTasksResponse']
_VODCREATEDOMAINV2RESPONSE = DESCRIPTOR.message_types_by_name['VodCreateDomainV2Response']
_VODUPDATEDOMAINEXPIREV2RESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateDomainExpireV2Response']
_VODUPDATEDOMAINAUTHCONFIGV2RESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateDomainAuthConfigV2Response']
_VODADDCALLBACKSUBSCRIPTIONRESPONSE = DESCRIPTOR.message_types_by_name['VodAddCallbackSubscriptionResponse']
_VODSETCALLBACKEVENTRESPONSE = DESCRIPTOR.message_types_by_name['VodSetCallbackEventResponse']
_VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoResponse']
_VODGETAPPINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetAppInfoResponse']
_DESCRIBEVODSPACETRANSCODEDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceTranscodeDataResponse']
_DESCRIBEVODSPACEAISTATISDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceAIStatisDataResponse']
_DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceSubtitleStatisDataResponse']
_DESCRIBEVODSPACEDETECTSTATISDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSpaceDetectStatisDataResponse']
_DESCRIBEVODSNAPSHOTDATARESPONSE = DESCRIPTOR.message_types_by_name['DescribeVodSnapshotDataResponse']
VodGetAllPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetAllPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETALLPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAllPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetAllPlayInfoResponse)

VodGetPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoResponse)

VodGetOriginalPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetOriginalPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETORIGINALPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetOriginalPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetOriginalPlayInfoResponse)

VodGetPrivateDrmPlayAuthResponse = _reflection.GeneratedProtocolMessageType('VodGetPrivateDrmPlayAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPRIVATEDRMPLAYAUTHRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPrivateDrmPlayAuthResponse)
  })
_sym_db.RegisterMessage(VodGetPrivateDrmPlayAuthResponse)

VodGetHlsDecryptionKeyResponse = _reflection.GeneratedProtocolMessageType('VodGetHlsDecryptionKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETHLSDECRYPTIONKEYRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetHlsDecryptionKeyResponse)
  })
_sym_db.RegisterMessage(VodGetHlsDecryptionKeyResponse)

VodGetPlayInfoWithLiveTimeShiftSceneResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoWithLiveTimeShiftSceneResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoWithLiveTimeShiftSceneResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoWithLiveTimeShiftSceneResponse)

VodUploadMediaResponse = _reflection.GeneratedProtocolMessageType('VodUploadMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUploadMediaResponse)
  })
_sym_db.RegisterMessage(VodUploadMediaResponse)

VodQueryUploadTaskInfoResponse = _reflection.GeneratedProtocolMessageType('VodQueryUploadTaskInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADTASKINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodQueryUploadTaskInfoResponse)
  })
_sym_db.RegisterMessage(VodQueryUploadTaskInfoResponse)

VodUrlUploadResponse = _reflection.GeneratedProtocolMessageType('VodUrlUploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUrlUploadResponse)
  })
_sym_db.RegisterMessage(VodUrlUploadResponse)

VodApplyUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodApplyUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoResponse)

VodCommitUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCommitUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResponse)

VodGetMediaInfosResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaInfosResponse)
  })
_sym_db.RegisterMessage(VodGetMediaInfosResponse)

VodUpdateMediaInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaInfoResponse)

VodGetRecommendedPosterResponse = _reflection.GeneratedProtocolMessageType('VodGetRecommendedPosterResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECOMMENDEDPOSTERRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetRecommendedPosterResponse)
  })
_sym_db.RegisterMessage(VodGetRecommendedPosterResponse)

VodUpdateMediaPublishStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaPublishStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaPublishStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaPublishStatusResponse)

VodUpdateMediaStorageClassResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaStorageClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIASTORAGECLASSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaStorageClassResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaStorageClassResponse)

VodDeleteMediaResponse = _reflection.GeneratedProtocolMessageType('VodDeleteMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteMediaResponse)
  })
_sym_db.RegisterMessage(VodDeleteMediaResponse)

VodDeleteTranscodesResponse = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteTranscodesResponse)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesResponse)

VodGetMediaListResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaListResponse)
  })
_sym_db.RegisterMessage(VodGetMediaListResponse)

VodGetSubtitleInfoListResponse = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSubtitleInfoListResponse)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListResponse)

VodUpdateSubtitleStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusResponse)

VodUpdateSubtitleInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLEINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleInfoResponse)

VodGetAuditFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAuditFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDITFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAuditFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAuditFramesForAuditResponse)

VodGetMLFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetMLFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMLFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMLFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetMLFramesForAuditResponse)

VodGetBetterFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetBetterFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditResponse)

VodGetAudioInfoForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioInfoForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditResponse)

VodGetAutomaticSpeechRecognitionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAutomaticSpeechRecognitionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditResponse)

VodGetAudioEventDetectionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioEventDetectionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditResponse)

VodCreateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationResponse)

VodUpdateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodUpdateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodUpdateVideoClassificationResponse)

VodDeleteVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodDeleteVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodDeleteVideoClassificationResponse)

VodListVideoClassificationsResponse = _reflection.GeneratedProtocolMessageType('VodListVideoClassificationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTVIDEOCLASSIFICATIONSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListVideoClassificationsResponse)
  })
_sym_db.RegisterMessage(VodListVideoClassificationsResponse)

VodListSnapshotsResponse = _reflection.GeneratedProtocolMessageType('VodListSnapshotsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSNAPSHOTSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSnapshotsResponse)
  })
_sym_db.RegisterMessage(VodListSnapshotsResponse)

VodGetFileListResponse = _reflection.GeneratedProtocolMessageType('VodGetFileListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETFILELISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetFileListResponse)
  })
_sym_db.RegisterMessage(VodGetFileListResponse)

VodExtractMediaMetaTaskResponse = _reflection.GeneratedProtocolMessageType('VodExtractMediaMetaTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODEXTRACTMEDIAMETATASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodExtractMediaMetaTaskResponse)
  })
_sym_db.RegisterMessage(VodExtractMediaMetaTaskResponse)

VodStartWorkflowResponse = _reflection.GeneratedProtocolMessageType('VodStartWorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodStartWorkflowResponse)
  })
_sym_db.RegisterMessage(VodStartWorkflowResponse)

VodRetrieveTranscodeResultResponse = _reflection.GeneratedProtocolMessageType('VodRetrieveTranscodeResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODRETRIEVETRANSCODERESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodRetrieveTranscodeResultResponse)
  })
_sym_db.RegisterMessage(VodRetrieveTranscodeResultResponse)

VodListWorkflowExecutionResponse = _reflection.GeneratedProtocolMessageType('VodListWorkflowExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTWORKFLOWEXECUTIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListWorkflowExecutionResponse)
  })
_sym_db.RegisterMessage(VodListWorkflowExecutionResponse)

VodGetWorkflowExecutionDetailResponse = _reflection.GeneratedProtocolMessageType('VodGetWorkflowExecutionDetailResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETWORKFLOWEXECUTIONDETAILRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetWorkflowExecutionDetailResponse)
  })
_sym_db.RegisterMessage(VodGetWorkflowExecutionDetailResponse)

VodGetWorkflowExecutionStatusResponse = _reflection.GeneratedProtocolMessageType('VodGetWorkflowExecutionStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETWORKFLOWEXECUTIONSTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetWorkflowExecutionStatusResponse)
  })
_sym_db.RegisterMessage(VodGetWorkflowExecutionStatusResponse)

VodGetWorkflowResultResponse = _reflection.GeneratedProtocolMessageType('VodGetWorkflowResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETWORKFLOWRESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetWorkflowResultResponse)
  })
_sym_db.RegisterMessage(VodGetWorkflowResultResponse)

VodSubmitDirectEditTaskAsyncResponse = _reflection.GeneratedProtocolMessageType('VodSubmitDirectEditTaskAsyncResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSUBMITDIRECTEDITTASKASYNCRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSubmitDirectEditTaskAsyncResponse)
  })
_sym_db.RegisterMessage(VodSubmitDirectEditTaskAsyncResponse)

VodGetDirectEditProgressResponse = _reflection.GeneratedProtocolMessageType('VodGetDirectEditProgressResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETDIRECTEDITPROGRESSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetDirectEditProgressResponse)
  })
_sym_db.RegisterMessage(VodGetDirectEditProgressResponse)

VodGetDirectEditResultResponse = _reflection.GeneratedProtocolMessageType('VodGetDirectEditResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETDIRECTEDITRESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetDirectEditResultResponse)
  })
_sym_db.RegisterMessage(VodGetDirectEditResultResponse)

VodCreateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodCreateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateSpaceResponse)
  })
_sym_db.RegisterMessage(VodCreateSpaceResponse)

VodListSpaceResponse = _reflection.GeneratedProtocolMessageType('VodListSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSpaceResponse)
  })
_sym_db.RegisterMessage(VodListSpaceResponse)

VodGetSpaceDetailResponse = _reflection.GeneratedProtocolMessageType('VodGetSpaceDetailResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSPACEDETAILRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSpaceDetailResponse)
  })
_sym_db.RegisterMessage(VodGetSpaceDetailResponse)

VodUpdateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceResponse)

VodUpdateSpaceUploadConfigResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceUploadConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEUPLOADCONFIGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceUploadConfigResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceUploadConfigResponse)

VodDescribeVodSpaceStorageDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodSpaceStorageDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODSPACESTORAGEDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodSpaceStorageDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodSpaceStorageDataResponse)

VodListDomainResponse = _reflection.GeneratedProtocolMessageType('VodListDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTDOMAINRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListDomainResponse)
  })
_sym_db.RegisterMessage(VodListDomainResponse)

VodCreateCdnRefreshTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnRefreshTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNREFRESHTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnRefreshTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnRefreshTaskResponse)

VodCreateCdnPreloadTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnPreloadTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNPRELOADTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnPreloadTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnPreloadTaskResponse)

VodListCdnTasksResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTasksResponse)
  })
_sym_db.RegisterMessage(VodListCdnTasksResponse)

VodListCdnAccessLogResponse = _reflection.GeneratedProtocolMessageType('VodListCdnAccessLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNACCESSLOGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnAccessLogResponse)
  })
_sym_db.RegisterMessage(VodListCdnAccessLogResponse)

VodListCdnTopAccessUrlResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTopAccessUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTOPACCESSURLRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTopAccessUrlResponse)
  })
_sym_db.RegisterMessage(VodListCdnTopAccessUrlResponse)

VodDescribeVodDomainBandwidthDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainBandwidthDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodDomainBandwidthDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainBandwidthDataResponse)

VodCdnStatisticsCommonResponse = _reflection.GeneratedProtocolMessageType('VodCdnStatisticsCommonResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCDNSTATISTICSCOMMONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCdnStatisticsCommonResponse)
  })
_sym_db.RegisterMessage(VodCdnStatisticsCommonResponse)

VodDescribeIPInfoResponse = _reflection.GeneratedProtocolMessageType('VodDescribeIPInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEIPINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeIPInfoResponse)
  })
_sym_db.RegisterMessage(VodDescribeIPInfoResponse)

VodDescribeVodDomainTrafficDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainTrafficDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodDomainTrafficDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainTrafficDataResponse)

VodSubmitBlockTasksResponse = _reflection.GeneratedProtocolMessageType('VodSubmitBlockTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSUBMITBLOCKTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSubmitBlockTasksResponse)
  })
_sym_db.RegisterMessage(VodSubmitBlockTasksResponse)

VodGetContentBlockTasksResponse = _reflection.GeneratedProtocolMessageType('VodGetContentBlockTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETCONTENTBLOCKTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetContentBlockTasksResponse)
  })
_sym_db.RegisterMessage(VodGetContentBlockTasksResponse)

VodCreateDomainV2Response = _reflection.GeneratedProtocolMessageType('VodCreateDomainV2Response', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEDOMAINV2RESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateDomainV2Response)
  })
_sym_db.RegisterMessage(VodCreateDomainV2Response)

VodUpdateDomainExpireV2Response = _reflection.GeneratedProtocolMessageType('VodUpdateDomainExpireV2Response', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEDOMAINEXPIREV2RESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateDomainExpireV2Response)
  })
_sym_db.RegisterMessage(VodUpdateDomainExpireV2Response)

VodUpdateDomainAuthConfigV2Response = _reflection.GeneratedProtocolMessageType('VodUpdateDomainAuthConfigV2Response', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEDOMAINAUTHCONFIGV2RESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateDomainAuthConfigV2Response)
  })
_sym_db.RegisterMessage(VodUpdateDomainAuthConfigV2Response)

VodAddCallbackSubscriptionResponse = _reflection.GeneratedProtocolMessageType('VodAddCallbackSubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODADDCALLBACKSUBSCRIPTIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodAddCallbackSubscriptionResponse)
  })
_sym_db.RegisterMessage(VodAddCallbackSubscriptionResponse)

VodSetCallbackEventResponse = _reflection.GeneratedProtocolMessageType('VodSetCallbackEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSETCALLBACKEVENTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSetCallbackEventResponse)
  })
_sym_db.RegisterMessage(VodSetCallbackEventResponse)

VodGetSmartStrategyLitePlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSmartStrategyLitePlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoResponse)

VodGetAppInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetAppInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAPPINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAppInfoResponse)
  })
_sym_db.RegisterMessage(VodGetAppInfoResponse)

DescribeVodSpaceTranscodeDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceTranscodeDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACETRANSCODEDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceTranscodeDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceTranscodeDataResponse)

DescribeVodSpaceAIStatisDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceAIStatisDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEAISTATISDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceAIStatisDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceAIStatisDataResponse)

DescribeVodSpaceSubtitleStatisDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceSubtitleStatisDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceSubtitleStatisDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceSubtitleStatisDataResponse)

DescribeVodSpaceDetectStatisDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceDetectStatisDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEDETECTSTATISDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSpaceDetectStatisDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSpaceDetectStatisDataResponse)

DescribeVodSnapshotDataResponse = _reflection.GeneratedProtocolMessageType('DescribeVodSnapshotDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSNAPSHOTDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.DescribeVodSnapshotDataResponse)
  })
_sym_db.RegisterMessage(DescribeVodSnapshotDataResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.responseB\013VodResponseP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Response\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETALLPLAYINFORESPONSE._serialized_start=433
  _VODGETALLPLAYINFORESPONSE._serialized_end=603
  _VODGETPLAYINFORESPONSE._serialized_start=606
  _VODGETPLAYINFORESPONSE._serialized_end=769
  _VODGETORIGINALPLAYINFORESPONSE._serialized_start=772
  _VODGETORIGINALPLAYINFORESPONSE._serialized_end=955
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_start=958
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_end=1145
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_start=1148
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_end=1331
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_start=1334
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_end=1545
  _VODUPLOADMEDIARESPONSE._serialized_start=1548
  _VODUPLOADMEDIARESPONSE._serialized_end=1708
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_start=1711
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_end=1878
  _VODURLUPLOADRESPONSE._serialized_start=1881
  _VODURLUPLOADRESPONSE._serialized_end=2044
  _VODAPPLYUPLOADINFORESPONSE._serialized_start=2047
  _VODAPPLYUPLOADINFORESPONSE._serialized_end=2222
  _VODCOMMITUPLOADINFORESPONSE._serialized_start=2225
  _VODCOMMITUPLOADINFORESPONSE._serialized_end=2402
  _VODGETMEDIAINFOSRESPONSE._serialized_start=2405
  _VODGETMEDIAINFOSRESPONSE._serialized_end=2574
  _VODUPDATEMEDIAINFORESPONSE._serialized_start=2576
  _VODUPDATEMEDIAINFORESPONSE._serialized_end=2677
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_start=2680
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_end=2855
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_start=2857
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_end=2967
  _VODUPDATEMEDIASTORAGECLASSRESPONSE._serialized_start=2970
  _VODUPDATEMEDIASTORAGECLASSRESPONSE._serialized_end=3159
  _VODDELETEMEDIARESPONSE._serialized_start=3162
  _VODDELETEMEDIARESPONSE._serialized_end=3327
  _VODDELETETRANSCODESRESPONSE._serialized_start=3330
  _VODDELETETRANSCODESRESPONSE._serialized_end=3505
  _VODGETMEDIALISTRESPONSE._serialized_start=3508
  _VODGETMEDIALISTRESPONSE._serialized_end=3675
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_start=3678
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_end=3859
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_start=3862
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_end=4045
  _VODUPDATESUBTITLEINFORESPONSE._serialized_start=4047
  _VODUPDATESUBTITLEINFORESPONSE._serialized_end=4151
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_start=4154
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_end=4338
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_start=4341
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_end=4522
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_start=4525
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_end=4716
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_start=4719
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_end=4904
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_start=4907
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_end=5126
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_start=5129
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_end=5334
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5337
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5530
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5532
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5643
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5645
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5756
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_start=5759
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_end=5946
  _VODLISTSNAPSHOTSRESPONSE._serialized_start=5949
  _VODLISTSNAPSHOTSRESPONSE._serialized_end=6113
  _VODGETFILELISTRESPONSE._serialized_start=6116
  _VODGETFILELISTRESPONSE._serialized_end=6283
  _VODEXTRACTMEDIAMETATASKRESPONSE._serialized_start=6285
  _VODEXTRACTMEDIAMETATASKRESPONSE._serialized_end=6391
  _VODSTARTWORKFLOWRESPONSE._serialized_start=6394
  _VODSTARTWORKFLOWRESPONSE._serialized_end=6565
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_start=6568
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_end=6742
  _VODLISTWORKFLOWEXECUTIONRESPONSE._serialized_start=6745
  _VODLISTWORKFLOWEXECUTIONRESPONSE._serialized_end=6932
  _VODGETWORKFLOWEXECUTIONDETAILRESPONSE._serialized_start=6935
  _VODGETWORKFLOWEXECUTIONDETAILRESPONSE._serialized_end=7132
  _VODGETWORKFLOWEXECUTIONSTATUSRESPONSE._serialized_start=7135
  _VODGETWORKFLOWEXECUTIONSTATUSRESPONSE._serialized_end=7314
  _VODGETWORKFLOWRESULTRESPONSE._serialized_start=7317
  _VODGETWORKFLOWRESULTRESPONSE._serialized_end=7487
  _VODSUBMITDIRECTEDITTASKASYNCRESPONSE._serialized_start=7490
  _VODSUBMITDIRECTEDITTASKASYNCRESPONSE._serialized_end=7682
  _VODGETDIRECTEDITPROGRESSRESPONSE._serialized_start=7685
  _VODGETDIRECTEDITPROGRESSRESPONSE._serialized_end=7863
  _VODGETDIRECTEDITRESULTRESPONSE._serialized_start=7866
  _VODGETDIRECTEDITRESULTRESPONSE._serialized_end=8040
  _VODCREATESPACERESPONSE._serialized_start=8042
  _VODCREATESPACERESPONSE._serialized_end=8139
  _VODLISTSPACERESPONSE._serialized_start=8142
  _VODLISTSPACERESPONSE._serialized_end=8299
  _VODGETSPACEDETAILRESPONSE._serialized_start=8302
  _VODGETSPACEDETAILRESPONSE._serialized_end=8464
  _VODUPDATESPACERESPONSE._serialized_start=8466
  _VODUPDATESPACERESPONSE._serialized_end=8563
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_start=8565
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_end=8674
  _VODDESCRIBEVODSPACESTORAGEDATARESPONSE._serialized_start=8677
  _VODDESCRIBEVODSPACESTORAGEDATARESPONSE._serialized_end=8876
  _VODLISTDOMAINRESPONSE._serialized_start=8879
  _VODLISTDOMAINRESPONSE._serialized_end=9044
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_start=9047
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_end=9225
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_start=9228
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_end=9406
  _VODLISTCDNTASKSRESPONSE._serialized_start=9409
  _VODLISTCDNTASKSRESPONSE._serialized_end=9573
  _VODLISTCDNACCESSLOGRESPONSE._serialized_start=9576
  _VODLISTCDNACCESSLOGRESPONSE._serialized_end=9753
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_start=9756
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_end=9939
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_start=9942
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_end=10147
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_start=10150
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_end=10333
  _VODDESCRIBEIPINFORESPONSE._serialized_start=10336
  _VODDESCRIBEIPINFORESPONSE._serialized_end=10498
  _VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE._serialized_start=10501
  _VODDESCRIBEVODDOMAINTRAFFICDATARESPONSE._serialized_end=10702
  _VODSUBMITBLOCKTASKSRESPONSE._serialized_start=10705
  _VODSUBMITBLOCKTASKSRESPONSE._serialized_end=10882
  _VODGETCONTENTBLOCKTASKSRESPONSE._serialized_start=10885
  _VODGETCONTENTBLOCKTASKSRESPONSE._serialized_end=11070
  _VODCREATEDOMAINV2RESPONSE._serialized_start=11072
  _VODCREATEDOMAINV2RESPONSE._serialized_end=11172
  _VODUPDATEDOMAINEXPIREV2RESPONSE._serialized_start=11174
  _VODUPDATEDOMAINEXPIREV2RESPONSE._serialized_end=11280
  _VODUPDATEDOMAINAUTHCONFIGV2RESPONSE._serialized_start=11282
  _VODUPDATEDOMAINAUTHCONFIGV2RESPONSE._serialized_end=11392
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_start=11394
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_end=11503
  _VODSETCALLBACKEVENTRESPONSE._serialized_start=11505
  _VODSETCALLBACKEVENTRESPONSE._serialized_end=11607
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_start=11610
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_end=11811
  _VODGETAPPINFORESPONSE._serialized_start=11814
  _VODGETAPPINFORESPONSE._serialized_end=11979
  _DESCRIBEVODSPACETRANSCODEDATARESPONSE._serialized_start=11982
  _DESCRIBEVODSPACETRANSCODEDATARESPONSE._serialized_end=12179
  _DESCRIBEVODSPACEAISTATISDATARESPONSE._serialized_start=12182
  _DESCRIBEVODSPACEAISTATISDATARESPONSE._serialized_end=12377
  _DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE._serialized_start=12380
  _DESCRIBEVODSPACESUBTITLESTATISDATARESPONSE._serialized_end=12587
  _DESCRIBEVODSPACEDETECTSTATISDATARESPONSE._serialized_start=12590
  _DESCRIBEVODSPACEDETECTSTATISDATARESPONSE._serialized_end=12793
  _DESCRIBEVODSNAPSHOTDATARESPONSE._serialized_start=12796
  _DESCRIBEVODSNAPSHOTDATARESPONSE._serialized_end=12981
# @@protoc_insertion_point(module_scope)
