# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_apps_manage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vod/business/vod_apps_manage.proto\x12\x1eVolcengine.Vod.Models.Business\"Z\n\x13VodGetAppInfoResult\x12\r\n\x05\x41ppId\x18\x01 \x01(\x04\x12\x0e\n\x06Scheme\x18\x02 \x01(\t\x12\x11\n\tAppEnName\x18\x03 \x01(\t\x12\x11\n\tAppCnName\x18\x04 \x01(\tB\xd1\x01\n)com.volcengine.service.vod.model.businessB\rVodAppsManageP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETAPPINFORESULT = DESCRIPTOR.message_types_by_name['VodGetAppInfoResult']
VodGetAppInfoResult = _reflection.GeneratedProtocolMessageType('VodGetAppInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAPPINFORESULT,
  '__module__' : 'vod.business.vod_apps_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAppInfoResult)
  })
_sym_db.RegisterMessage(VodGetAppInfoResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\rVodAppsManageP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETAPPINFORESULT._serialized_start=70
  _VODGETAPPINFORESULT._serialized_end=160
# @@protoc_insertion_point(module_scope)
